diff --git a/module/programplan/ui/create.html.php b/module/programplan/ui/create.html.php
index 8ff1518fcb..4dc7d578c9 100644
--- a/module/programplan/ui/create.html.php
+++ b/module/programplan/ui/create.html.php
@@ -59,7 +59,7 @@ $fnGenerateStageByProductList = function() use ($productID, $productList, $proje
};
/* Generate checkboxes for sub-stage management. */
-$fnGenerateSubPlanManageFields = function() use ($lang, $planID, $project, $executionType, $canParallel)
+$fnGenerateSubPlanManageFields = function() use ($lang, $planID, $project, $canParallel)
{
if(!(empty($planID) && $project->model == 'ipd')) return div();
diff --git a/module/project/ui/execution.html.php b/module/project/ui/execution.html.php
index 2334b57284..a0f653e7f3 100644
--- a/module/project/ui/execution.html.php
+++ b/module/project/ui/execution.html.php
@@ -60,8 +60,8 @@ if($canBatchAction)
$fieldList = $config->project->execution->dtable->fieldList;
$fieldList['status']['statusMap']['changed'] = $lang->task->storyChange;
-/* waterfall & waterfallplus model with different edit link. */
-if(in_array($project->model, array('waterfall', 'waterfallplus')))
+/* waterfall & waterfallplus & ipd model with different edit link. */
+if(in_array($project->model, array('waterfall', 'waterfallplus', 'ipd')))
{
$fieldList['actions']['actionsMap']['edit']['data-size'] = 'md';
$fieldList['actions']['actionsMap']['edit']['url'] = createLink('programplan', 'edit', "stageID={rawID}&projectID={projectID}");